bioneuralnet.utils.logger — BioNeuralNet 1.0.4 documentation

# bioneuralnet.utils.logger

Functions

`get_logger`(name) | Retrieves a global logger configured to write to 'bioneuralnet.log' at the project root.

bioneuralnet.utils.logger.get_logger(name: str) → Logger

  Retrieves a global logger configured to write to ‘bioneuralnet.log’ at the project root.

  Parameters:

    name (str) – Name of the logger.

  Returns:

    Configured logger instance.

  Return type:

    logging.Logger